fn distinct_course_codes(modules: &[SuotarModuleConfigFacts]) -> Vec<CourseCode>Expand description
The modules’ course codes as the registry is asked about them: trimmed, sorted, each once.
fn distinct_course_codes(modules: &[SuotarModuleConfigFacts]) -> Vec<CourseCode>The modules’ course codes as the registry is asked about them: trimmed, sorted, each once.